@@ -32,12 +32,6 @@ impl<'a> TreeRefIter<'a> {
     }
 }
 
-impl<'a> Default for TreeRefIter<'a> {
-    fn default() -> Self {
-        TreeRefIter { data: &[] }
-    }
-}
-
 impl<'a> Iterator for TreeRefIter<'a> {
     type Item = Result<EntryRef<'a>, crate::decode::Error>;
 
@@ -139,7 +133,7 @@ mod decode {
             EntryRef {
                 mode,
                 filename: filename.as_bstr(),
-                oid: git_hash::oid::try_from(oid).expect("we counted exactly 20 bytes"),
+                oid: git_hash::oid::try_from_bytes(oid).expect("we counted exactly 20 bytes"),
             },
         ))
     }
@@ -156,7 +150,7 @@ mod decode {
             EntryRef {
                 mode,
                 filename: filename.as_bstr(),
-                oid: git_hash::oid::try_from(oid).expect("we counted exactly 20 bytes"),
+                oid: git_hash::oid::try_from_bytes(oid).expect("we counted exactly 20 bytes"),
             },
         ))
     }
